@@ -58,14 +58,9 @@ class PaymentFormMixin(object):
             'success_url': success_url,
             'fail_url': fail_url,
             'error_url': fail_url,
+            'existing_txns': AsiaPayTransaction.objects.filter(
+                order_number=self.order.number),
         })
-        try:
-            context.update({
-                'existing_txn': AsiaPayTransaction.objects.get(
-                    order_number=self.order.number),
-            })
-        except AsiaPayTransaction.DoesNotExist:
-            pass
         return context
 # --- END MIXINS ---
 
